/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.xmlconfig.mapping;

import java.util.ArrayList;
import java.util.List;

/**
 * Common methods used by mapping class.
 * @author Florent Benoit
 */
public abstract class AbsMapping {

    /**
     * List of aliases for this mapping.
     */
    private List<String> aliases;

    /**
     * Name of the mapping element.
     */
    private String name = null;

    /**
     * Default constructor.
     */
    public AbsMapping() {
        this.aliases = new ArrayList<String>();
    }

    /**
     * Gets name of this mapping element.
     * @return the name.
     */
    public String getName() {
        return this.name;
    }

    /**
     * Sets the name for this mapping.
     * @param name the given name.
     */
    public void setName(final String name) {
        this.name = name;
    }

    /**
     * Sets the aliases for this mapping.
     * @param aliases the given aliases.
     */
    public void setAliases(final List<String> aliases) {
        this.aliases = aliases;
    }

    /**
     * Gets aliases used.
     * @return the aliases of this mapping class.
     */
    public List<String> getAliases() {
        return aliases;
    }

    /**
     * Returns a string representation of the object.
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("name=");
        sb.append(name);
        sb.append(", aliases=");
        sb.append(aliases);
        return sb.toString();
    }
}
