/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.xmlconfig.mapping;

/**
 * Defines a mapping for attributes of a class.
 * @author Florent Benoit
 */
public class AttributeMapping extends AbsMapping {

    /**
     * Value of this element has to be used (this is not an xml attribute).<br>
     * Default is false.
     */
    private boolean isElement = false;

    /**
     * Element should be used as a List.
     */
    private boolean isListElement = false;

    /**
     * Getter to use.
     */
    private String getter = null;

    /**
     * Setter to use.
     */
    private String setter = null;
    
    /**
     * Is the attribute optional ?
     */
    private boolean isOptional = false;


    /**
     * This attribute is mapped to an XML element ?
     */
    public void setElement() {
        this.isElement = true;
    }

    /**
     * Is that this attribute is mapped to an XML element ?
     * @return true if it the case
     */
    public boolean isElement() {
        return this.isElement;
    }

    /**
     * This attribute is considered as a List.
     */
    public void setListElement() {
        this.isListElement = true;
    }

    /**
     * Is that this attribute should be considered as a list ?
     * @return true if it the case
     */
    public boolean isListElement() {
        return this.isListElement;
    }

    /**
     * @return the getter for this attribute.
     */
    public String getGetter() {
        return getter;
    }

    /**
     * Sets the getter for this attribute.
     * @param getter the given getter name
     */
    public void setGetter(final String getter) {
        this.getter = getter;
    }

    /**
     * @return the setter for this attribute.
     */
    public String getSetter() {
        return setter;
    }

    /**
     * Sets the setter for this attribute.
     * @param setter the given setter name
     */
    public void setSetter(final String setter) {
        this.setter = setter;
    }

    /**
     * This attribute is considered optional.
     */
    public void setOptional() {
        this.isOptional = true;
    }

    /**
     * Is that this attribute should be considered as optional ?
     * @return true if it the case
     */
    public boolean isOptional() {
        return this.isOptional;
    }

    /**
     * Returns a string representation of the object.
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));
        sb.append("[");
        sb.append(super.toString());
        if (isElement) {
            sb.append(", isElement=");
            sb.append(isElement);
        }
        if (isListElement) {
            sb.append(", isListElement=");
            sb.append(isListElement);
        }
        if (isOptional) {
            sb.append(", isOptional=");
            sb.append(isOptional);
        }
        sb.append("]");

        return sb.toString();
    }

}
