/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.xmlconfig.mapping;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Defines a mapping for a given class.
 * @author Florent Benoit
 */
public class ClassMapping extends AbsMapping {

    /**
     * Association between a name(or alias) and an attribute mapping.
     */
    private Map<String, AttributeMapping> attributesMapping = null;


    /**
     * The text of this element must be set on an attribute.
     */
    private String elementAttribute = null;


    /**
     * @return the name of the attribute to use when finding a value inside this element.
     */
    public String getElementAttribute() {
        return elementAttribute;
    }

    /**
     * Sets the name of the element attribute for this class.
     * @param elementAttribute the value of the attribute to map the XML element.
     */
    public void setElementAttribute(final String elementAttribute) {
        this.elementAttribute = elementAttribute;
    }

    /**
     * Build a default class mapping.
     */
    public ClassMapping() {
        super();
        this.attributesMapping = new HashMap<String, AttributeMapping>();
    }

    /**
     * Add a given attribute mapping object.
     * @param attributeMapping the given attribute.
     */
    public void addAttributeMapping(final AttributeMapping attributeMapping) {
        attributesMapping.put(attributeMapping.getName(), attributeMapping);

        // Always non-null list (but may be empty)
        List<String> aliases = attributeMapping.getAliases();

        // store alias too (if any)
        if (!aliases.isEmpty()) {
            for (String alias : aliases) {
                attributesMapping.put(alias, attributeMapping);
            }
        }
    }

    /**
     * Gets the attribute mapping for the given attribute name.
     * @param attributeName the given attribute name.
     * @return the attribute mapping or null if not found.
     */
    public AttributeMapping getAttributeMapping(final String attributeName) {
        return attributesMapping.get(attributeName);
    }

    /**
     * Returns a string representation of the object.
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));
        sb.append("[");
        sb.append(super.toString());
        sb.append(", attributes=");
        sb.append(attributesMapping);
        sb.append("]");

        return sb.toString();
    }

}
