/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.xmlconfig.mapping;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Mapping for a given name space.<br>
 * It contains all classes mapping.
 * @author Florent Benoit
 */
public class XMLMapping {

    /**
     * Association between class name (and alias) and the given class mapping.
     */
    private Map<String, ClassMapping> classMappings = null;

    /**
     * Default constructor.
     */
    public XMLMapping() {
        this.classMappings = new HashMap<String, ClassMapping>();
    }

    /**
     * Add a given class mapping object.
     * @param classMapping the given class.
     */
    public void addClassMapping(final ClassMapping classMapping) {
        classMappings.put(classMapping.getName(), classMapping);

        // Always non-null list (but may be empty)
        List<String> aliases = classMapping.getAliases();

        // store alias too (if any)
        if (!aliases.isEmpty()) {
            for (String alias : aliases) {
                classMappings.put(alias, classMapping);
            }
        }

    }

    /**
     * Gets the class mapping for the given class name.
     * @param className the given className.
     * @return the class mapping or null if not found.
     */
    public ClassMapping getClassMapping(final String className) {
        return classMappings.get(className);
    }

    /**
     * Returns a string representation of the object.
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));
        sb.append("[classMappings=");
        sb.append(classMappings);
        sb.append("]");

        return sb.toString();
    }
}
