/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.xmlconfig.properties;

import java.util.ArrayList;
import java.util.List;

/**
 * A {@code ChainedPropertyResolver} is responsible to call each resolver
 * from a list of resolver. The first one that returns a alue wins.
 *
 * @author Guillaume Sauthier
 */
public class ChainedPropertyResolver implements IPropertyResolver {

    /**
     * List of property resolvers.
     */
    private List<IPropertyResolver> resolvers;

    public ChainedPropertyResolver() {
        this.resolvers = new ArrayList<IPropertyResolver>();
    }

    public List<IPropertyResolver> getResolvers() {
        return this.resolvers;
    }

    public String resolve(final String name) {

        // Return the first resolved value (if any)
        for (IPropertyResolver resolver : resolvers) {
            String value = resolver.resolve(name);
            if (value != null) {
                return value;
            }
        }
        return null;
    }
}
