/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.xmlconfig.source;

import java.io.InputStream;

import org.ow2.util.xml.DocumentParser;
import org.ow2.util.xml.DocumentParserException;
import org.w3c.dom.Document;

/**
 * This {@link IConfigurationSource} wraps an {@link InputStream}.
 * @author Guillaume Sauthier
 */
public class InputStreamConfigurationSource implements IConfigurationSource {

    /**
     * Name of the stream.
     */
    private String name;

    /**
     * Stream.
     */
    private InputStream stream;

    /**
     * Constructs a new {@link IConfigurationSource} based on {@link InputStream}.
     * @param name stream's name
     * @param stream the stream to be parsed
     */
    public InputStreamConfigurationSource(final String name, final InputStream stream) {
        this.name = name;
        this.stream = stream;
    }

    /**
     * Parse the configuration source's content.
     * @param validating is the parser validating ?
     * @return the parsed Document
     * @throws DocumentParserException if the document cannot be parsed or is not valid.
     */
    public Document getDocument(final boolean validating) throws DocumentParserException {
        return DocumentParser.getDocument(stream, validating, null);
    }

    /**
     * @return the name of the source (useful for textual representation).
     */
    public String getName() {
        return name;
    }

}
